@@ -71,11 +71,13 @@ def convert_to_easypost_object(response, api_key):
             'Rate': Rate,
             'Refund': Refund,
             'Batch': Batch,
+            'Event': Event,
             'Tracker': Tracker,
             'PostageLabel': PostageLabel }
 
   prefixes = { 'adr': Address,
             'sf': ScanForm,
+            'evt': Event,
             'cstitem': CustomsItem,
             'cstinfo': CustomsInfo,
             'prcl': Parcel,
@@ -643,6 +645,13 @@ class Batch(AllResource, CreateResource):
     response, api_key = requestor.request('post', url, wrapped_params)
     return convert_to_easypost_object(response, api_key)
 
+  def buy(self, **params):
+    requestor = Requestor(self.api_key)
+    url = "%s/%s" % (self.instance_url(), "buy")
+    response, api_key = requestor.request('post', url, params)
+    self.refresh_from(response, api_key)
+    return self
+
   def label(self, **params):
     requestor = Requestor(self.api_key)
     url = "%s/%s" % (self.instance_url(), "label")
@@ -670,3 +679,8 @@ class PostageLabel(AllResource, CreateResource):
 class Tracker(AllResource, CreateResource):
   pass
 
+class Event(Resource):
+
+  def receive(self, values):
+    self.refresh_from(values, None)
+
